@@ -7,14 +7,14 @@ import gettext
 import os
 
 # local packages
-from .DataOutput import DataOutput
-from .DataInput import DataInput
+from .DataDiskRead import DataDiskRead
+from .DataDiskWrite import DataDiskWrite
 
 
-class DataInputOutput(DataInput, DataOutput):
+class DataInputOutput(DataDiskRead, DataDiskWrite):
     locale = None
 
-    def __init__(self, in_language = 'en_US'):
+    def __init__(self, in_language):
         file_parts = os.path.normpath(os.path.abspath(__file__)).replace('\\', os.path.altsep) \
             .split(os.path.altsep)
         locale_domain = file_parts[(len(file_parts) - 1)].replace('.py', '')
@@ -30,6 +30,8 @@ class DataInputOutput(DataInput, DataOutput):
             in_dict['field delimiter'] = os.pathsep
         if 'compression' not in in_dict:
             in_dict['compression'] = 'infer'
+        if 'worksheet list' not in in_dict:
+            in_dict['worksheet list'] = 0
         return in_dict
 
     def fn_build_feedback_for_logger(self, operation_details):
@@ -61,6 +63,26 @@ class DataInputOutput(DataInput, DataOutput):
             }
         return messages
 
+    def fn_implemented_file_format_validation(self, local_logger, in_file_details):
+        given_format_is_implemented = False
+        if 'format' in in_file_details:
+            given_format_is_implemented = True
+            if in_file_details['format'].lower() not in self.implemented_disk_write_file_types:
+                given_format_is_implemented = False
+                local_logger.error(self.locale.gettext(
+                        'File "format" attribute has a value of "{format_value}" '
+                        + 'which is not among currently implemented values: '
+                        + '"{implemented_file_formats}", '
+                        + 'therefore desired file operation is not possible')
+                                   .replace('{format_value}', in_file_details['format'].lower())
+                                   .replace('{implemented_file_formats}',
+                                            '", "'.join(self.implemented_disk_write_file_types)))
+        else:
+            local_logger.error(self.locale.gettext(
+                    'File "format" attribute is mandatory in the file setting, but missing, '
+                    + 'therefore desired file operation is not possible'))
+        return given_format_is_implemented
+
     def fn_file_operation_logger(self, local_logger, in_logger_dict):
         messages = self.fn_build_feedback_for_logger(in_logger_dict)
         if in_logger_dict['error details'] is None:
@@ -71,7 +93,7 @@ class DataInputOutput(DataInput, DataOutput):
 
     def fn_load_file_into_data_frame(self, in_logger, timer, in_dict):
         timer.start()
-        if self.fn_store_data_frame_to_file_validation(in_logger, in_dict):
+        if self.fn_implemented_file_format_validation(in_logger, in_dict):
             in_dict = self.fn_add_missing_defaults_to_dict_message(in_dict)
             in_dict.update({'operation': 'load'})
             in_dict = self.fn_pack_dict_message(in_dict, in_dict['file list'])
@@ -92,7 +114,8 @@ class DataInputOutput(DataInput, DataOutput):
         return {
             'compression'    : in_dict['compression'],
             'field delimiter': in_dict['field delimiter'],
-            'files list'     : in_file_list,
+            'files list'     : in_dict['file list'],
+            'worksheet list' : in_dict['worksheet list'],
             'files counted'  : len(in_file_list),
             'error details'  : None,
             'format'         : in_dict['format'],
@@ -104,7 +127,7 @@ class DataInputOutput(DataInput, DataOutput):
 
     def fn_store_data_frame_to_file(self, in_logger, timer, in_data_frame, in_dict):
         timer.start()
-        if self.fn_store_data_frame_to_file_validation(in_logger, in_dict):
+        if self.fn_implemented_file_format_validation(in_logger, in_dict):
             in_dict = self.fn_add_missing_defaults_to_dict_message(in_dict)
             in_dict.update({'operation': 'save'})
             in_dict = self.fn_pack_dict_message(in_dict, [])
@@ -117,25 +140,3 @@ class DataInputOutput(DataInput, DataOutput):
             in_dict = self.fn_internal_store_data_frame_to_pickle_file(in_dict)
             self.fn_file_operation_logger(in_logger, in_dict)
         timer.stop()
-
-    def fn_store_data_frame_to_file_validation(self, local_logger, in_file_details):
-        given_format_is_implemented = False
-        if 'format' in in_file_details:
-            implemented_file_formats = ['csv', 'excel', 'json', 'parquet', 'pickle']
-            given_format = in_file_details['format'].lower()
-            given_format_is_implemented = True
-            if given_format not in implemented_file_formats:
-                given_format_is_implemented = False
-                local_logger.error(self.locale.gettext(
-                        'File "format" attribute has a value of "{format_value}" '
-                        + 'which is not among currently implemented values: '
-                        + '"{implemented_file_formats}", '
-                        + 'therefore desired file operation is not possible')
-                                   .replace('{format_value}', given_format)
-                                   .replace('{implemented_file_formats}',
-                                            '", "'.join(implemented_file_formats)))
-        else:
-            local_logger.error(self.locale.gettext(
-                    'File "format" attribute is mandatory in the file setting, but missing, '
-                    + 'therefore desired file operation is not possible'))
-        return given_format_is_implemented
